==> blesta-5.10.2.zip: blesta/components/gateways/nonmerchant/paypal_payments_standard/language/id_id/paypal_payments_standard.php <==
<?php
/**
 * Paypal Payments Standard
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['PaypalPaymentsStandard.pay_type_both'] = 'Pembayaran satu kali dan langganan jika memungkinkan';
$lang['PaypalPaymentsStandard.pay_type_subscribe'] = 'Hanya pembayaran langganan';
$lang['PaypalPaymentsStandard.pay_type_onetime'] = 'Hanya satu kali pembayaran';
$lang['PaypalPaymentsStandard.pay_type'] = 'Opsi Pembayaran';
$lang['PaypalPaymentsStandard.api_signature'] = 'Tanda Tangan API';
$lang['PaypalPaymentsStandard.api_password'] = 'Kata Sandi API';
$lang['PaypalPaymentsStandard.api_username_note'] = 'Hal ini, serta Kata Sandi API dan Tanda Tangan API, diperlukan untuk memproses pengembalian dana melalui PayPal.';
$lang['PaypalPaymentsStandard.!error.dev_mode.valid'] = 'Mode pengembang harus diatur ke "true" jika diberikan.';
$lang['PaypalPaymentsStandard.!error.account_id.valid'] = 'Anda harus memasukkan alamat email yang valid.';
$lang['PaypalPaymentsStandard.buildprocess.submit'] = 'Bayar dengan PayPal';
$lang['PaypalPaymentsStandard.api_username'] = 'Nama Pengguna API';
$lang['PaypalPaymentsStandard.dev_mode_note'] = 'Mengaktifkan opsi ini akan memposting transaksi ke lingkungan PayPal Sandbox. Hanya aktifkan opsi ini jika Anda menguji dengan akun PayPal Sandbox.';
$lang['PaypalPaymentsStandard.dev_mode'] = 'Mode Pengembang';
$lang['PaypalPaymentsStandard.page_style_note'] = 'Nama Gaya Halaman dari tema halaman pembayaran khusus yang Anda buat di PayPal. Biarkan kosong untuk gaya halaman default.';
$lang['PaypalPaymentsStandard.page_style'] = 'Nama Gaya Halaman';
$lang['PaypalPaymentsStandard.account_id'] = 'Email Akun PayPal';
$lang['PaypalPaymentsStandard.description'] = 'Standar Pembayaran PayPal adalah salah satu cara termudah untuk menerima pembayaran kartu kredit dan PayPal secara online dengan aman';
$lang['PaypalPaymentsStandard.name'] = 'PayPal Payments Standard';

==> blesta-5.11.4.zip: blesta/components/gateways/nonmerchant/paypal_payments_standard/language/id_id/paypal_payments_standard.php <==
<?php
/**
 * Paypal Payments Standard
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['PaypalPaymentsStandard.pay_type_both'] = 'Pembayaran satu kali dan langganan jika memungkinkan';
$lang['PaypalPaymentsStandard.pay_type_subscribe'] = 'Hanya pembayaran langganan';
$lang['PaypalPaymentsStandard.pay_type_onetime'] = 'Hanya satu kali pembayaran';
$lang['PaypalPaymentsStandard.pay_type'] = 'Opsi Pembayaran';
$lang['PaypalPaymentsStandard.api_signature'] = 'Tanda Tangan API';
$lang['PaypalPaymentsStandard.api_password'] = 'Kata Sandi API';
$lang['PaypalPaymentsStandard.api_username_note'] = 'Hal ini, serta Kata Sandi API dan Tanda Tangan API, diperlukan untuk memproses pengembalian dana melalui PayPal.';
$lang['PaypalPaymentsStandard.!error.dev_mode.valid'] = 'Mode pengembang harus diatur ke "true" jika diberikan.';
$lang['PaypalPaymentsStandard.!error.account_id.valid'] = 'Anda harus memasukkan alamat email yang valid.';
$lang['PaypalPaymentsStandard.buildprocess.submit'] = 'Bayar dengan PayPal';
$lang['PaypalPaymentsStandard.api_username'] = 'Nama Pengguna API';
$lang['PaypalPaymentsStandard.dev_mode_note'] = 'Mengaktifkan opsi ini akan memposting transaksi ke lingkungan PayPal Sandbox. Hanya aktifkan opsi ini jika Anda menguji dengan akun PayPal Sandbox.';
$lang['PaypalPaymentsStandard.dev_mode'] = 'Mode Pengembang';
$lang['PaypalPaymentsStandard.page_style_note'] = 'Nama Gaya Halaman dari tema halaman pembayaran khusus yang Anda buat di PayPal. Biarkan kosong untuk gaya halaman default.';
$lang['PaypalPaymentsStandard.page_style'] = 'Nama Gaya Halaman';
$lang['PaypalPaymentsStandard.account_id'] = 'Email Akun PayPal';
$lang['PaypalPaymentsStandard.description'] = 'Standar Pembayaran PayPal adalah salah satu cara termudah untuk menerima pembayaran kartu kredit dan PayPal secara online dengan aman';
$lang['PaypalPaymentsStandard.name'] = 'PayPal Payments Standard';
$lang['PaypalPaymentsStandard.!error.payment_mapping.duplicated'] = 'Ditemukan email duplikat dalam data pemetaan Anda, hapus duplikat dan coba lagi.';
$lang['PaypalPaymentsStandard.!error.payment_mapping.valid'] = 'Ditemukan baris yang tidak valid pada data pemetaan Anda, periksa apakah alamat email dan ID Klien valid dan coba lagi.';
$lang['PaypalPaymentsStandard.payment_mapping_note'] = 'Dimaksudkan untuk digunakan dengan Langganan PayPal yang dibuat di luar Blesta. Memetakan payer_email ke ID Klien internal, 1 per baris. Sebagai contoh: email, client-id';
$lang['PaypalPaymentsStandard.payment_mapping'] = 'Pemetaan Pembayaran';
